<?php
/**
 * Siteorigin Panels Compatibility File
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Registers custom builder.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function roku_builders_init() {

	// Banner builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/banner.php';
	register_widget( 'Roku_Banner_Builder' );

	// Big Banner builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/big-banner.php';
	register_widget( 'Roku_Big_Banner_Builder' );

	// Latest product slider builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/latest-products-slider.php';
	register_widget( 'Roku_Latest_Product_Slider_Builder' );

	// Sale product slider builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/sale-products-slider.php';
	register_widget( 'Roku_Sale_Product_Slider_Builder' );

	// Featured product slider builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/featured-products-slider.php';
	register_widget( 'Roku_Featured_Product_Slider_Builder' );

	// Popular product slider builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/popular-products-slider.php';
	register_widget( 'Roku_Popular_Product_Slider_Builder' );

	// Category product builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/category-products.php';
	register_widget( 'Roku_Category_Product_Builder' );

	// Latest posts builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/latest-posts.php';
	register_widget( 'Roku_Latest_Posts_Builder' );

	// Call to action builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/call-action.php';
	register_widget( 'Roku_Call_Action_Builder' );

	// Simple text builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/simple-text.php';
	register_widget( 'Roku_Simple_Text_Builder' );

	// Google maps builder
	require trailingslashit( get_template_directory() ) . 'inc/builder/maps.php';
	register_widget( 'Roku_Maps_Builder' );
}
add_action( 'widgets_init', 'roku_builders_init' );

/**
 * Add new panel
 *
 * @since 1.0.0
 */
function roku_panels_add_widgets_dialog_tabs( $tabs ){

	$tabs[] = array(
		'title'  => esc_html__( 'Roku Widgets', 'roku' ),
		'filter' => array(
			'installed' => true,
			'groups'    => array( 'roku' )
		)
	);

	return $tabs;
}
add_filter( 'siteorigin_panels_widget_dialog_tabs', 'roku_panels_add_widgets_dialog_tabs' );

/**
 * Set the groups for all Roku Widgets
 *
 * @since 1.0.0
 */
function roku_panels_add_widget_groups( $widgets ){
	$widgets['LayerSlider_Widget']['groups'] = array( 'roku' );
	$widgets['Roku_Banner_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Big_Banner_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Latest_Product_Slider_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Sale_Product_Slider_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Featured_Product_Slider_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Popular_Product_Slider_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Category_Product_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Latest_Posts_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Call_Action_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Simple_Text_Builder']['groups'] = array( 'roku' );
	$widgets['Roku_Maps_Builder']['groups'] = array( 'roku' );
	return $widgets;
}
add_filter( 'siteorigin_panels_widgets', 'roku_panels_add_widget_groups' );

/**
 * Change the margin bottom between block.
 *
 * @since 1.0.0
 */
function roku_panels_margin_bottom( $panels_margin_bottom ) {
	$panels_margin_bottom = '50px';
	return $panels_margin_bottom;
}
add_filter( 'siteorigin_panels_css_row_margin_bottom', 'roku_panels_margin_bottom', 10, 4 );

/**
 * Filter the widget output
 *
 * @since 1.0.0
 */
function roku_panels_widget_args( $args ) {
	$args['before_title'] = '<h3 class="widget-title"><span>';
	$args['after_title']  = '</span></h3>';
	return $args;
}
add_filter( 'siteorigin_panels_widget_args', 'roku_panels_widget_args' );

/**
 * Adds default page layouts
 *
 * @since 1.0.0
 */
function roku_prebuilt_page_layouts( $layouts ) {

	$layouts['default-home'] = array (
		'name'        => esc_html__( 'Default Home', 'roku' ),
		'description' => esc_html__( 'Prebuilt layout for home page', 'roku' ),

		'widgets' =>
		array(
			0 =>
			array(
				'id'    => '',
				'title' => esc_html__( 'Home Slider', 'roku' ),
				'info'  => array(
					'class' => 'LayerSlider_Widget',
					'id'    => '1',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			1 =>
			array(
				'info'  => array(
					'class' => 'SiteOrigin_Panels_Widgets_Layout',
					'id'    => '2',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			2 =>
			array(
				'position' => 'left',
				'title'    => '',
				'subtitle' => '',
				'btntext'  => '',
				'url'      => '',
				'img'      => '',
				'info'  => array(
					'class' => 'Roku_Big_Banner_Builder',
					'id'    => '3',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			3 =>
			array(
				'info'  => array(
					'class' => 'SiteOrigin_Panels_Widgets_Layout',
					'id'    => '4',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
			4 =>
			array(
				'text'  => '',
				'info'  => array(
					'class' => 'Roku_Simple_Text_Builder',
					'id'    => '5',
					'grid'  => '0',
					'cell'  => '0',
				),
			),
		),

		'grids' =>
		array(
			0 =>
			array(
				'cells' => '1',
				'style' => '',
			),
		),

		'grid_cells' =>
		array(
			0 =>
			array(
				'weight' => '1',
				'grid'   => '0',
			),
		),
	);

	return $layouts;

}
add_filter( 'siteorigin_panels_prebuilt_layouts', 'roku_prebuilt_page_layouts' );
