<?php
/**
 * Banner builder.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Banner_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'banner-builder',
			'description' => esc_html__( 'Easily to display custom banner.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-baner-builder',           // $this->id_base
			esc_html__( 'Banner', 'roku' ), // $this->name
			$widget_options                 // $this->widget_options
		);

		// Loads the media dialog scripts
		add_action( 'admin_print_scripts-widgets.php', array( $this, 'upload_scripts' ) );
		add_action( 'siteorigin_panel_enqueue_admin_scripts', array( $this, 'upload_scripts' ) );

	}

	/**
	 * Upload the Javascripts for the media uploader
	 */
	function upload_scripts() {
		// Loads required media files for the media manager.
		wp_enqueue_media();

		// Custom script for the image uploader.
		wp_enqueue_script( 'roku-banner-widget-media', trailingslashit( get_template_directory_uri() ) . 'admin/js/banner-widget-media.js', array( 'jquery' ), null, true );

		// Localize custom JS.
		wp_localize_script( 'roku-banner-widget-media', 'roku_banner_widget_media',
			array(
				'title'  => esc_html__( 'Upload Image', 'roku' ),
				'button' => esc_html__( 'Add Image', 'roku' )
			)
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// Get the attachment id
		$id = attachment_url_to_postid( $instance['img'] );

		if ( $id ) :

			echo '<div class="banner-promotion">';
				echo '<a href="' . esc_url( $instance['url'] ) . '">';
					echo wp_get_attachment_image( $id, 'roku-banner' );
					echo '<span class="img-cover"></span>';
					echo '<span class="banner-title-wrapper"><span class="banner-title">' . esc_attr( $instance['title'] ) . '</span></span>';
				echo '</a>';
			echo '</div>';

		endif;

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['url']   = esc_url_raw( $new_instance['url'] );
		$instance['img']   = esc_url_raw( $new_instance['img'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title' => '',
			'url'   => '',
			'img'   => ''
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>">
				<?php esc_html_e( 'Url', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_url( $instance['url'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'img' ); ?>">
				<?php esc_html_e( 'Image', 'roku' ); ?>
			</label>
			<input type="text" class="widefat img-url" id="<?php echo $this->get_field_id( 'img' ); ?>" name="<?php echo $this->get_field_name( 'img' ); ?>" value="<?php echo esc_url( $instance['img'] ); ?>" />
			<a href="#" class="roku-widget-upload upload_image_button button button-primary" style="margin-top: 10px;"><?php esc_html_e( 'Upload Image', 'roku' ); ?></a>
		</p>

	<?php

	}

}
