<?php
/**
 * Big Banner builder.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Big_Banner_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'big-banner-builder',
			'description' => esc_html__( 'Easily to display custom big banner.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-big-banner-builder',  // $this->id_base
			esc_html__( 'Big Banner', 'roku' ), // $this->name
			$widget_options             // $this->widget_options
		);

		// Loads the media dialog scripts
		add_action( 'admin_print_scripts-widgets.php', array( $this, 'upload_scripts' ) );
		add_action( 'siteorigin_panel_enqueue_admin_scripts', array( $this, 'upload_scripts' ) );

	}

	/**
	 * Upload the Javascripts for the media uploader
	 */
	function upload_scripts() {
		// Loads required media files for the media manager.
		wp_enqueue_media();

		// Custom script for the image uploader.
		wp_enqueue_script( 'roku-big-banner-widget-media', trailingslashit( get_template_directory_uri() ) . 'admin/js/big-banner-widget-media.js', array( 'jquery' ), null, true );

		// Localize custom JS.
		wp_localize_script( 'roku-big-banner-widget-media', 'roku_big_banner_widget_media',
			array(
				'title'  => esc_html__( 'Upload Image', 'roku' ),
				'button' => esc_html__( 'Add Image', 'roku' )
			)
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// Get the attachment id
		$id = attachment_url_to_postid( $instance['img'] );

		if ( $id ) :

			echo '<div class="big-banner ' . esc_attr( $instance['position'] ) . ' " style="background-image: url(' . wp_get_attachment_url( $id, 'full' ) . ')">';
				echo '<div class="container">';
					echo '<h3 class="big-banner-title">' . esc_attr( $instance['title'] ) . '</h3>';
					echo '<p class="big-banner-subtitle">' . esc_attr( $instance['subtitle'] ) . '</p>';
					echo '<a class="button" href="' . esc_url( $instance['url'] ) . '">' . esc_attr( $instance['btntext'] ) . ' <i class="fa fa-angle-right"></i></a>';
				echo '</div>';
			echo '</div>';

		endif;

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['position'] = strip_tags( $new_instance['position'] );
		$instance['title']    = strip_tags( $new_instance['title'] );
		$instance['subtitle'] = strip_tags( $new_instance['subtitle'] );
		$instance['btntext']  = strip_tags( $new_instance['btntext'] );
		$instance['url']      = esc_url_raw( $new_instance['url'] );
		$instance['img']      = esc_url_raw( $new_instance['img'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'position' => 'left',
			'title'    => '',
			'subtitle' => '',
			'btntext'  => '',
			'url'      => '',
			'img'      => ''
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'position' ); ?>">
				<?php esc_html_e( 'Text Position', 'roku' ); ?>
			</label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'position' ); ?>" name="<?php echo $this->get_field_name( 'position' ); ?>" style="width:100%;">
				<option value="left" <?php selected( $instance['position'], 'left' ); ?>><?php esc_html_e( 'Left', 'roku' ) ?></option>
				<option value="center" <?php selected( $instance['position'], 'center' ); ?>><?php esc_html_e( 'Center', 'roku' ) ?></option>
				<option value="right" <?php selected( $instance['position'], 'right' ); ?>><?php esc_html_e( 'Right', 'roku' ) ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'subtitle' ); ?>">
				<?php esc_html_e( 'Sub Title', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'subtitle' ); ?>" name="<?php echo $this->get_field_name( 'subtitle' ); ?>" value="<?php echo esc_attr( $instance['subtitle'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'btntext' ); ?>">
				<?php esc_html_e( 'Button Text', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'btntext' ); ?>" name="<?php echo $this->get_field_name( 'btntext' ); ?>" value="<?php echo esc_attr( $instance['btntext'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>">
				<?php esc_html_e( 'Button URL', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_url( $instance['url'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'img' ); ?>">
				<?php esc_html_e( 'Image', 'roku' ); ?>
			</label>
			<input type="text" class="widefat big-banner-url" id="<?php echo $this->get_field_id( 'img' ); ?>" name="<?php echo $this->get_field_name( 'img' ); ?>" value="<?php echo esc_url( $instance['img'] ); ?>" />
			<a href="#" class="roku-big-banner-upload upload_image_button button button-primary" style="margin-top: 10px;"><?php esc_html_e( 'Upload Image', 'roku' ); ?></a>
		</p>

	<?php

	}

}
