<?php
/**
 * Call to action builder
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Call_Action_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'call-action-builder',
			'description' => esc_html__( 'Call to action block.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-call-action-builder',     // $this->id_base
			esc_html__( 'Call to action', 'roku' ), // $this->name
			$widget_options                 // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Display the call to action.
			if ( $instance['text'] ) {
				echo '<div class="call-to-action">' . esc_attr( $instance['text'] ) . ' <a href="' . esc_url( $instance['url'] ) . '">' . esc_attr( $instance['btntext'] ) . ' <i class="fa fa-angle-right"></i></a></div>';
			}

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['text']    = strip_tags( $new_instance['text'] );
		$instance['btntext'] = strip_tags( $new_instance['btntext'] );
		$instance['url']     = esc_url_raw( $new_instance['url'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'text'    => '',
			'btntext' => esc_html__( 'More Details', 'roku' ),
			'url'     => '',
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'text' ); ?>">
				<?php esc_html_e( 'Text', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>" value="<?php echo esc_attr( $instance['text'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'btntext' ); ?>">
				<?php esc_html_e( 'Button Text', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'btntext' ); ?>" name="<?php echo $this->get_field_name( 'btntext' ); ?>" value="<?php echo esc_attr( $instance['btntext'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>">
				<?php esc_html_e( 'URL', 'roku' ); ?>
			</label>
			<input type="url" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_url( $instance['url'] ); ?>" />
		</p>

	<?php

	}

}
