<?php
/**
 * Category product builder
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Category_Product_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'category-product-builder',
			'description' => esc_html__( 'Display list of product categories.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-category-product-builder',    // $this->id_base
			esc_html__( 'Product Categories', 'roku' ), // $this->name
			$widget_options                     // $this->widget_options
		);

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
		}

		$cats = get_terms( 'product_cat' );
		?>
			<ul class="product-categories">

				<?php $i = 0; ?>
				<?php foreach( $cats as $cat ) : ?>

					<?php
						$class = 'bd-top';
						if ( $i++ < 5 ) {
							$class = '';
						}
					?>

					<?php
						$id = get_woocommerce_term_meta( $cat->term_id, 'thumbnail_id', true );
						if ( $id ) :
					?>
						<li class="category <?php echo esc_attr( $class ); ?>">
							<a href="<?php echo esc_url( get_term_link( $cat ) ) ?>">
								<?php echo wp_get_attachment_image( $id, 'shop_catalog' ); ?>
								<span class="name"><?php echo esc_attr( $cat->name ); ?></span>
							</a>
						</li>
					<?php endif; ?>

				<?php endforeach; ?>

			</ul>
		<?php

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title' => esc_html__( 'Shop by Category', 'roku' )
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

	<?php

	}

}
