<?php
/**
 * Google Maps builder.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Maps_Builder extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'maps-builder',
			'description' => esc_html__( 'Display google maps for your contact page.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-maps-builder',         // $this->id_base
			esc_html__( 'Google Maps', 'roku' ), // $this->name
			$widget_options              // $this->widget_options
		);

		// Loads the google maps scripts
		add_action( 'wp_enqueue_scripts', array( $this, 'maps_script' ) );

	}

	function maps_script() {
		wp_enqueue_script( 'roku-google-maps', '//maps.googleapis.com/maps/api/js', array( 'jquery' ), null, false );
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;
		?>
		<div id="map"></div>
		<style>
			#map {
				height: 500px;
				width: 100%;
			}
		</style>
		<script>
			( function() {
				var userMap = function() {
					var cord = {
						lat: <?php echo strip_tags( $instance['lat'] ); ?>,
						lng: <?php echo strip_tags( $instance['long'] ); ?>
					};

					var map = new google.maps.Map( document.getElementById( 'map' ), {
						zoom: <?php echo strip_tags( $instance['zoom'] ); ?>,
						center: cord,
						scrollwheel: false
					});

					var marker = new google.maps.Marker({
						position: cord,
						map: map,
						title: ""
					});
				}
				userMap();
			}() );
		</script>
		<?php
		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['long']  = strip_tags( $new_instance['long'] );
		$instance['lat']   = strip_tags( $new_instance['lat'] );
		$instance['zoom']  = strip_tags( $new_instance['zoom'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'long' => '',
			'lat'  => '',
			'zoom' => 17
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'lat' ); ?>">
				<?php esc_html_e( 'Latitude', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'lat' ); ?>" name="<?php echo $this->get_field_name( 'lat' ); ?>" value="<?php echo esc_attr( $instance['lat'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'long' ); ?>">
				<?php esc_html_e( 'Longitude', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'long' ); ?>" name="<?php echo $this->get_field_name( 'long' ); ?>" value="<?php echo esc_attr( $instance['long'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'zoom' ); ?>">
				<?php esc_html_e( 'Zoom', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'zoom' ); ?>" name="<?php echo $this->get_field_name( 'zoom' ); ?>" value="<?php echo esc_attr( $instance['zoom'] ); ?>" />
		</p>

	<?php

	}

}
