<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function roku_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //

	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'          => $general_panel,
		'title'       => esc_html__( 'General', 'roku' ),
		'description' => esc_html__( 'This panel is used for managing general section of your site.', 'roku' ),
		'priority'    => 10
	);

		// RSS
		$section = PREFIX . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'RSS', 'roku' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => esc_html__( 'If you fill the custom rss url below, it will replace the default.', 'roku' ),
		);
		$options[PREFIX . 'custom-rss'] = array(
			'id'           => PREFIX . 'custom-rss',
			'label'        => esc_html__( 'Custom RSS URL (eg. Feedburner)', 'roku' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = PREFIX . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Comments', 'roku' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'page-comment'] = array(
			'id'           => PREFIX . 'page-comment',
			'label'        => esc_html__( 'Page Comment', 'roku' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Footer Text
		$section = PREFIX . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Footer Text', 'roku' ),
			'priority'    => 120,
			'panel'       => $general_panel,
		);
		$options[PREFIX . 'footer-text'] = array(
			'id'           => PREFIX . 'footer-text',
			'label'        => '',
			'description'  => esc_html__( 'Customize the footer text.', 'roku' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>'
		);

	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'          => $header_panel,
		'title'       => esc_html__( 'Header', 'roku' ),
		'description' => esc_html__( 'This panel is used for managing header section of your site.', 'roku' ),
		'priority'    => 15
	);

		// Logo
		$section = PREFIX . 'logo-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Logo', 'roku' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'logo'] = array(
			'id'      => PREFIX . 'logo',
			'label'   => esc_html__( 'Regular Logo', 'roku' ),
			'section' => $section,
			'type'    => 'media',
			'default' => ''
		);

		// Product search form
		$section = PREFIX . 'product-search-form-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Product Search Form', 'roku' ),
			'priority'    => 35,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'product-search-form'] = array(
			'id'      => PREFIX . 'product-search-form',
			'label'   => esc_html__( 'Show product search form', 'roku' ),
			'section' => $section,
			'type'    => 'switch',
			'default' => 1
		);

		// Cart
		$section = PREFIX . 'header-cart-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Header Cart', 'roku' ),
			'priority'    => 40,
			'panel'       => $header_panel
		);
		$options[PREFIX . 'header-cart'] = array(
			'id'      => PREFIX . 'header-cart',
			'label'   => esc_html__( 'Show header cart', 'roku' ),
			'section' => $section,
			'type'    => 'switch',
			'default' => 1
		);

	// Colors Panel and Sections
	$color_panel = 'color';

	$panels[] = array(
		'id'          => $color_panel,
		'title'       => esc_html__( 'Color', 'roku' ),
		'description' => esc_html__( 'This panel is used for managing colors of your site.', 'roku' ),
		'priority'    => 20
	);

		// Predefined color
		$section = PREFIX . 'predefined-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Predefined Skins', 'roku' ),
			'priority'    => 5,
			'panel'       => $color_panel
		);
		$options[PREFIX . 'skins'] = array(
			'id'          => PREFIX . 'skins',
			'label'       => esc_html__( 'Skins', 'roku' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => 'default',
			'choices'     => array(
				'default' => esc_html__( 'Default', 'roku' ),
				'green'   => esc_html__( 'Green', 'roku' ),
				'black'   => esc_html__( 'Black', 'roku' ),
				'cyan'    => esc_html__( 'Cyan', 'roku' ),
				'magenta' => esc_html__( 'Magenta', 'roku' ),
			)
		);

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'          => $typo_panel,
		'title'       => esc_html__( 'Typography', 'roku' ),
		'description' => esc_html__( 'This panel is used for managing typography of your site.', 'roku' ),
		'priority'    => 30
	);

		// Global typography
		$section = PREFIX . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => esc_html__( 'Global', 'roku' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[PREFIX . 'text-font'] = array(
			'id'          => PREFIX . 'text-font',
			'label'       => esc_html__( 'Text font', 'roku' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Work Sans',
		);
		$options[PREFIX . 'heading-font'] = array(
			'id'          => PREFIX . 'heading-font',
			'label'       => esc_html__( 'Heading font', 'roku' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Work Sans',
		);

	// Content Panel and Sections
	$content_panel = 'layouts';

	$panels[] = array(
		'id'          => $content_panel,
		'title'       => esc_html__( 'Layouts', 'roku' ),
		'description' => esc_html__( 'This panel is used for managing several custom features/layouts of your site.', 'roku' ),
		'priority'    => 35
	);

		// Container
		$section = PREFIX . 'container-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Container', 'roku' ),
			'priority'    => 4,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'container-layouts'] = array(
			'id'          => PREFIX . 'container-layouts',
			'label'       => esc_html__( 'Container layouts', 'roku' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => 'fullwidth',
			'choices'     => array(
				'fullwidth' => esc_html__( 'Full Width', 'roku' ),
				'boxed'     => esc_html__( 'Boxed', 'roku' ),
				'framed'    => esc_html__( 'Framed', 'roku' )
			)
		);

		// Container Width
		$section = PREFIX . 'container-width-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Container Width', 'roku' ),
			'description' => esc_html__( 'Set up the maximum width of the layout. (default: 1230)', 'roku' ),
			'priority'    => 5,
			'panel'       => $content_panel,
		);
		$options[PREFIX . 'container-width'] = array(
			'id'           => PREFIX . 'container-width',
			'label'        => esc_html__( 'Width', 'roku' ),
			'description'  => esc_html__( 'Please be careful with this option. If you set the width larger, it possibly will break your images. Please be wise to set the maximum width. Unit in pixel.', 'roku' ),
			'section'      => $section,
			'type'         => 'number',
			'default'      => 1230
		);

		// Shop
		$section = PREFIX . 'shop-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Shop', 'roku' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'shop-layouts'] = array(
			'id'          => PREFIX . 'shop-layouts',
			'label'       => esc_html__( 'Shop layouts', 'roku' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => '1c',
			'choices'     => array(
				'1c'   => esc_html__( '1 Column Wide (Full Width)', 'roku' ),
				'1c-n' => esc_html__( '1 Column Narrow (Full Width)', 'roku' ),
				'2c-l' => esc_html__( '2 Columns: Content / Sidebar', 'roku' ),
				'2c-r' => esc_html__( '2 Columns: Sidebar / Content', 'roku' )
			)
		);

		// Blog
		$section = PREFIX . 'blog-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Blog', 'roku' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'blog-layouts'] = array(
			'id'          => PREFIX . 'blog-layouts',
			'label'       => esc_html__( 'Blog layouts', 'roku' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => '2c-l',
			'choices'     => array(
				'1c'   => esc_html__( '1 Column Wide (Full Width)', 'roku' ),
				'1c-n' => esc_html__( '1 Column Narrow (Full Width)', 'roku' ),
				'2c-l' => esc_html__( '2 Columns: Content / Sidebar', 'roku' ),
				'2c-r' => esc_html__( '2 Columns: Sidebar / Content', 'roku' )
			)
		);
		$options[PREFIX . 'blog-list-layouts'] = array(
			'id'          => PREFIX . 'blog-list-layouts',
			'label'       => esc_html__( 'Blog list layouts', 'roku' ),
			'section'     => $section,
			'type'        => 'radio',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => esc_html__( 'Standard', 'roku' ),
				'grid'     => esc_html__( 'Grid', 'roku' ),
			)
		);

		// Posts
		$section = PREFIX . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Posts', 'roku' ),
			'description' => esc_html__( 'Posts is a single post page.', 'roku' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'post-meta-group'] = array(
			'id'          => PREFIX . 'post-meta-group',
			'label'       => esc_html__( 'Post Meta', 'roku' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-date'] = array(
				'id'          => PREFIX . 'post-date',
				'label'       => esc_html__( 'Show post date', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-share'] = array(
				'id'          => PREFIX . 'post-share',
				'label'       => esc_html__( 'Show post share', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-author-box'] = array(
				'id'          => PREFIX . 'post-author-box',
				'label'       => esc_html__( 'Show post author box', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[PREFIX . 'post-date-group'] = array(
			'id'          => PREFIX . 'post-date-group',
			'label'       => esc_html__( 'Post Date', 'roku' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-date-style'] = array(
				'id'          => PREFIX . 'post-date-style',
				'label'       => esc_html__( 'Style', 'roku' ),
				'section'     => $section,
				'type'        => 'select',
				'default'     => 'absolute',
				'choices'     => array(
					'absolute' => esc_html__( 'Absolute (June 20, 2015 10:19 am)', 'roku' ),
					'relative' => esc_html__( 'Relative (1 week ago)', 'roku' )
				)
			);
		$options[PREFIX . 'post-footer-group'] = array(
			'id'          => PREFIX . 'post-footer-group',
			'label'       => esc_html__( 'Category and Tag', 'roku' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'post-cat'] = array(
				'id'          => PREFIX . 'post-cat',
				'label'       => esc_html__( 'Show post categories', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'post-tag'] = array(
				'id'          => PREFIX . 'post-tag',
				'label'       => esc_html__( 'Show post tags', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[PREFIX . 'related-posts-group'] = array(
			'id'          => PREFIX . 'related-posts-group',
			'label'       => esc_html__( 'Related Posts', 'roku' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[PREFIX . 'related-posts'] = array(
				'id'          => PREFIX . 'related-posts',
				'label'       => esc_html__( 'Show related posts', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[PREFIX . 'related-posts-img'] = array(
				'id'          => PREFIX . 'related-posts-img',
				'label'       => esc_html__( 'Show related posts thumbnail', 'roku' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);

		// Page
		$section = PREFIX . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => esc_html__( 'Page', 'roku' ),
			'priority'    => 15,
			'panel'       => $content_panel
		);
		$options[PREFIX . 'page-title'] = array(
			'id'          => PREFIX . 'page-title',
			'label'       => esc_html__( 'Show page title', 'roku' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'roku_customizer_register' );
