<?php
/**
 * Stock Filter widget.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Roku_Stock_Filter_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-stock-filter widget_layered_nav',
			'description' => esc_html__( 'Shows an in/out options in a widget which lets you narrow down the list of available products.', 'roku' )
		);

		// Create the widget.
		parent::__construct(
			'roku-stock-filter',          // $this->id_base
			esc_html__( 'Stock Filter', 'roku' ), // $this->name
			$widget_options               // $this->widget_options
		);

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
		}

		global $_chosen_attributes;

		if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
			return;
		}

		$current_stock = get_query_var( 'stock' );

		echo '<ul>';

		// Base Link decided by current page
		if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
			$link = home_url();
		} elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id('shop') ) ) {
			$link = get_post_type_archive_link( 'product' );
		} else {
			$link = get_term_link( get_query_var('term'), get_query_var('taxonomy') );
		}

		// All current filters from Layered Nav
		if ( $_chosen_attributes ) {
			foreach ( $_chosen_attributes as $name => $data ) {
				// Remove pa_ and sanitize
				$filter_name = sanitize_title( str_replace( 'pa_', '', $name ) );

				if ( ! empty( $data['terms'] ) ) {
					$link = add_query_arg( 'filter_' . $filter_name, implode( ',', $data['terms'] ), $link );
				}

				if ( 'or' == $data['query_type'] ) {
					$link = add_query_arg( 'query_type_' . $filter_name, 'or', $link );
				}
			}
		}

		// Min/Max
		if ( isset( $_GET['min_price'] ) ) {
			$link = add_query_arg( 'min_price', $_GET['min_price'], $link );
		}

		if ( isset( $_GET['max_price'] ) ) {
			$link = add_query_arg( 'max_price', $_GET['max_price'], $link );
		}

		// Orderby
		if ( isset( $_GET['orderby'] ) ) {
			$link = add_query_arg( 'orderby', $_GET['orderby'], $link );
		}

		// Search Arg
		if ( get_search_query() ) {
			$link = add_query_arg( 's', get_search_query(), $link );
		}

		// Post Type Arg
		if ( isset( $_GET['post_type'] ) ) {
			$link = add_query_arg( 'post_type', $_GET['post_type'], $link );
		}

		// instock
		if ( isset( $current_stock ) && ( 'in' == $current_stock ) ) {
			$class = 'class="chosen"';
		} else {
			$class = '';
			$link = add_query_arg( 'stock', 'in', $link );
		}
		echo '<li ' . $class . '>';

		echo '<a href="' . esc_url( apply_filters( 'roku_stock_filter_link', $link ) ) . '">';

		esc_html_e( 'Available', 'roku' );

		echo '</a>';

		echo '</li>';


		// outofstock
		if ( isset( $current_stock ) && ( 'out' == $current_stock ) ) {
			$class = 'class="chosen"';
			$link = remove_query_arg( 'stock', $link );
		} else {
			$class = '';
			$link = add_query_arg( 'stock', 'out', $link );
		}
		echo '<li ' . $class . '>';

		echo '<a href="' . esc_url( apply_filters( 'roku_stock_filter_link', $link ) ) . '">';

		esc_html_e( 'Sold Out', 'roku' );

		echo '</a>';

		echo '</li>';


		echo '</ul>';

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;
		$instance['title']     = strip_tags( $new_instance['title'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'     => esc_html__( 'Filter by Stock', 'roku' )
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php esc_html_e( 'Title', 'roku' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

	<?php

	}

}
