<?php
/**
 * Custom template tags used to integrate this theme with WooCommerce.
 *
 * @package    Roku
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'roku_header_cart' ) ) :
/**
 * Display Header Cart
 *
 * @since  1.0.0
 */
function roku_header_cart() {
		// Show hide cart based on user selected on Customizer.
		$show = roku_mod( PREFIX . 'header-cart' );
		if ( !$show ) {
			return;
		}
	?>
		<div class="header-cart">
			<span class="cart-box">
				<?php roku_cart_link(); ?>
			</span>
			<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'roku_cart_link' ) ) :
/**
 * Cart link
 *
 * @since  1.0.0
 */
function roku_cart_link() { ?>
	<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_html_e( 'View your shopping cart', 'roku' ); ?>">
		<span class="cart-data">
			<span class="total"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span>
			<span class="count">(<?php echo wp_kses_data( WC()->cart->get_cart_contents_count() );?>)</span>
		</span>
		<i class="fa fa-shopping-cart"></i>
	</a>
	<?php
}
endif;

if ( ! function_exists( 'roku_before_content' ) ) :
/**
 * Before Content
 * Wraps all WooCommerce content in wrappers which match the theme markup
 *
 * @since   1.0.0
 */
function roku_before_content() {
	?>
	<div id="primary" class="content-area">
		<main id="main" class="site-main">
		<?php
}
endif;

if ( ! function_exists( 'roku_after_content' ) ) :
/**
 * After Content
 * Closes the wrapping divs
 *
 * @since   1.0.0
 */
function roku_after_content() {
	?>
		</main><!-- #main -->
	</div><!-- #primary -->

	<?php
}
endif;

if ( ! function_exists( 'roku_sorting_wrapper' ) ) :
/**
 * Sorting wrapper
 *
 * @since   1.0.0
 */
function roku_sorting_wrapper() {
	echo '<div class="roku-sorting">';
}
endif;

if ( ! function_exists( 'roku_sorting_wrapper_close' ) ) :
/**
 * Sorting wrapper close
 *
 * @since   1.0.0
 */
function roku_sorting_wrapper_close() {
	echo '</div>';
}
endif;

if ( ! function_exists( 'roku_upsell_display' ) ) :
/**
 * Upsells
 * Replace the default upsell function with our own which displays the correct number product columns
 *
 * @since   1.0.0
 */
function roku_upsell_display() {
	woocommerce_upsell_display();
}
endif;

if ( ! function_exists( 'roku_add_to_wishlist' ) ) :
/**
 * Add to wishlist
 *
 * @since   1.0.0
 */
function roku_add_to_wishlist() {

	if ( class_exists( 'YITH_WCWL_Shortcode' ) ) {
		echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
	}

}
endif;

if ( ! function_exists( 'roku_hide_page_title' ) ) :
/**
 * Removes the "Shop" title on the main shop page
 *
 * @since  1.0.0
 * @return void
*/
function roku_hide_page_title() {
	return false;
}
endif;

if ( ! function_exists( 'roku_shop_sidebar' ) ) :
/**
 * Add custom shop sidebar
 *
 * @since  1.0.0
*/
function roku_shop_sidebar() {
	get_template_part( 'sidebar', 'shop-filter' );
}
endif;

if ( ! function_exists( 'roku_product_nav' ) ) :
/**
 * Add custom next/prev navigation
 *
 * @since  1.0.0
*/
function roku_product_nav() {
	get_template_part( 'loop', 'nav' );
}
endif;

if ( ! function_exists( 'roku_loop_product_actions' ) ) :
/**
 * Add product actions, consist of:
 * - before hook (add to cart hooked here)
 * - popup image full
 * - after hook
 *
 * @since  1.0.0
*/
function roku_loop_product_actions() {
	?>
	<div class="product-actions">
		<?php do_action( 'roku_product_actions_before' ); ?>
		<a href="<?php echo esc_url( wp_get_attachment_url( get_post_thumbnail_id() ) ); ?>" class="popup-image"><i class="fa fa-search"></i></a>
		<?php do_action( 'roku_product_actions_after' ); ?>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'roku_image_wrapper_open' ) ) :
/**
 * Sorting wrapper
 *
 * @since   1.0.0
 */
function roku_image_wrapper_open() {
	echo '<div class="img-wrapper">';
}
endif;

if ( ! function_exists( 'roku_image_wrapper_close' ) ) :
/**
 * Sorting wrapper close
 *
 * @since   1.0.0
 */
function roku_image_wrapper_close() {
	echo '</div>';
}
endif;

if ( ! function_exists( 'roku_more_filters_link' ) ) :
/**
 * More filters link
 *
 * @since   1.0.0
 */
function roku_more_filters_link() {

	// Hide on search page.
	if ( is_search() ) {
		return;
	}

	// Check if 'shop-filter' sidebar has active widgets.
	if ( ! is_active_sidebar( 'shop-filter' ) ) {
		return;
	}

	$text = sprintf( __( '%1$s %2$s Filters &hellip;', 'roku' ),
		sprintf( __( '<span class="more">More</span>', 'roku' ) ),
		sprintf( __( '<span class="close">Close</span>', 'roku' ) )
	);

	echo '<a class="more-filters" href="#">' . $text . '</a>';
}
endif;

if ( ! function_exists( 'roku_product_flash' ) ) :
/**
 * Product Flash:
 * - Out of Stock
 * - New
 * - Sale
 *
 * Out of Stock Flash ref:
 * http://businessbloomer.com/woocommerce-show-sold-archiveproduct-page/
 *
 * New Flash ref:
 * https://github.com/jameskoster/woocommerce-new-product-badge/blob/master/new-badge.php
 *
 * @since   1.0.0
 */
function roku_product_flash() {

	global $post, $product;

	$postdate 		= get_the_time( 'Y-m-d' ); // Post date
	$postdatestamp 	= strtotime( $postdate ); // Timestamped post date
	$newness 		= apply_filters( 'roku_new_product_flash_days', 5 ); // Newness in days as defined by option

	// out of stock flash
	if ( ! $product->is_in_stock() ) {
		echo apply_filters( 'roku_woocommerce_outofstock_flash', '<span class="onsale outofstock">' . esc_html__( 'Sold Out', 'roku' ) . '</span>', $post, $product );

	// sale flash
	} elseif ( $product->is_on_sale() ) {
		echo apply_filters( 'roku_woocommerce_sale_flash', '<span class="onsale">' . esc_html__( 'Sale!', 'roku' ) . '</span>', $post, $product );

	// If the product was published within the newness time frame display the new flash
	} elseif ( ( time() - ( 60 * 60 * 24 * $newness ) ) < $postdatestamp ) {
		echo apply_filters( 'roku_woocommerce_new_flash', '<span class="onsale new">' . esc_html__( 'New', 'roku' ) . '</span>', $post, $product );

	}

}
endif;

if ( ! function_exists( 'roku_product_terms' ) ) :
/**
 * List all product category terms
 *
 * @since 1.0.0
 */
function roku_product_terms() {

	// Get the terms
	$terms = get_terms( 'product_cat' );

	// Display terms in select option
	if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) :
		echo '<select name="term" class="beautify-select">';
			echo '<option value="">' . esc_html__( 'All Categories', 'roku' ) . '</option>';
			foreach ( $terms as $term ) {
				echo '<option value="' . esc_attr( $term->slug ) . '">' . esc_attr( $term->name ) . '</option>';
			}
		echo '</select>';
	endif;
}
endif;
