<?php
// Get the data set in customizer
$cat        = roku_mod( PREFIX . 'post-cat' );
$date       = roku_mod( PREFIX . 'post-date' );
$tag        = roku_mod( PREFIX . 'post-tag' );
$date_style = roku_mod( PREFIX . 'post-date-style' );

// Set up empty variable
$style = '';
if ( $date_style == 'absolute' ) {
	$style = esc_html( get_the_date() );
} else {
	$style = sprintf( esc_html__( '%s ago', 'roku' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
}
?>
<article id="post-<?php the_ID(); ?>" <?php post_class(); ?> <?php hybrid_attr( 'post' ); ?>>

	<meta itemscope itemprop="mainEntityOfPage" itemType="https://schema.org/WebPage" itemid="<?php the_permalink(); ?>" content="<?php echo esc_attr( get_the_title() ); ?>" />

	<header class="entry-header">

		<?php if ( 'post' == get_post_type() ) : ?>
			<?php
				/* translators: used between list items, there is a space after the comma */
				$categories_list = get_the_category_list( esc_html__( ', ', 'roku' ) );
				if ( $categories_list && roku_categorized_blog() && $cat ) :
			?>
			<span class="cat-links" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
				<?php echo $categories_list; ?>
			</span>
			<?php endif; // End if categories ?>
		<?php endif; ?>

		<?php if ( $date ) : ?>
			<time class="entry-date published" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( $style ); ?></time>

			<meta itemprop="dateModified" content="<?php echo esc_attr( get_the_modified_date( 'c' ) ); ?>"/>
		<?php endif; ?>

		<?php the_title( '<h1 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '>', '</h1>' ); ?>

		<div <?php hybrid_attr( 'entry-author' ) ?>>
			<meta itemprop="name" content="<?php echo strip_tags( get_the_author() ); ?>" />
		</div>

	</header>

	<?php if ( has_post_format( 'video' ) ) : ?>
		<div class="entry-format">
			<?php echo hybrid_media_grabber( array( 'type' => 'video', 'split_media' => true ) ); ?>
		</div>
	<?php elseif ( has_post_format( 'audio' ) ) : ?>
		<div class="entry-format">
			<?php echo hybrid_media_grabber( array( 'type' => 'audio', 'split_media' => true ) ); ?>
		</div>
	<?php elseif ( ! has_post_format( 'quote' ) ) : ?>
		<?php if ( has_post_thumbnail() ) : ?>
			<a class="thumbnail-link" href="<?php the_permalink(); ?>">
				<?php the_post_thumbnail( 'large', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
			</a>
		<?php endif; ?>
	<?php endif; ?>

	<?php if ( has_post_thumbnail() ) : ?>
		<div itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
			<meta itemprop="url" content="<?php echo esc_url( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>">
			<meta itemprop="width" content="300">
			<meta itemprop="height" content="200">
		</div>
	<?php endif; ?>

	<div class="entry-content" <?php hybrid_attr( 'entry-content' ); ?>>

		<?php the_content(); ?>
		<?php
			wp_link_pages( array(
				'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'roku' ),
				'after'  => '</div>',
			) );
		?>

	</div>

	<?php roku_entry_publisher(); ?>

	<footer class="entry-footer">

		<?php
			$tags = get_the_tags();
			if ( $tags && $tag ) :
		?>
			<span class="tag-links" <?php hybrid_attr( 'entry-terms', 'post_tag' ); ?>>
				<?php foreach( $tags as $tag ) : ?>
					<a href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>">#<?php echo esc_attr( $tag->name ); ?></a>
				<?php endforeach; ?>
			</span>
		<?php endif; ?>

		<?php roku_entry_share(); ?>

	</footer>

	<?php if ( function_exists( 'sharing_display' ) ) : ?>
		<div class="jetpack-share-like">
			<?php sharing_display( '', true ); ?>
			<?php if ( class_exists( 'Jetpack_Likes' ) ) { $custom_likes = new Jetpack_Likes; echo $custom_likes->post_likes( '' ); } ?>
		</div>
	<?php endif; ?>

</article><!-- #post-## -->
